@@ -14,6 +14,7 @@ import traceback
 from urlparse import urlparse
 import xml.dom.minidom
 import zipfile
+import numpy
 
 import mozlog
 from progressbar import Counter
@@ -28,7 +29,7 @@ from marionette.gestures import smooth_scroll
 from wait import MarionetteWait
 
 TEST_TYPES = ['startup', 'scrollfps']
-
+SCROLLFPS_APP_NAMES = ['browser', 'contacts', 'email', 'homescreen']
 
 class DatazillaPerfPoster(object):
 
@@ -161,6 +162,10 @@ class B2GPerfRunner(DatazillaPerfPoster):
             self.logger.info('Running startup tests')
             self.test_startup()
         elif test_type == 'scrollfps':
+            for app_name in self.app_names:
+                if app_name.lower() not in SCROLLFPS_APP_NAMES:
+                    self.logger.error("%s is not a valid scrollfps test app name. Please select one of %s" % (app_name, SCROLLFPS_APP_NAMES))
+                    sys.exit(1)
             self.logger.info('Running FPS tests')
             self.test_scrollfps()
         else:
@@ -259,8 +264,10 @@ class B2GPerfRunner(DatazillaPerfPoster):
                     self.post_to_datazilla(results, app_name)
                 else:
                     for key, values in results.iteritems():
-                        result_summary = 'avg:%s, max:%s, min:%s, all:%s' % (
-                            sum(values) / len(values),
+                        result_summary = 'median:%s, mean:%s, std: %s, max:%s, min:%s, all:%s' % (
+                            int(numpy.median(values)),
+                            int(numpy.mean(values)),
+                            int(numpy.std(values)),
                             max(values),
                             min(values),
                             ','.join(str(x) for x in values))
@@ -336,6 +343,11 @@ class B2GPerfRunner(DatazillaPerfPoster):
 
                             app = apps.launch(app_name, switch_to_frame=False)
 
+                            # Prepare app
+                            self.marionette.switch_to_frame(app.frame)
+                            self.prepare_app(app_name)
+                            self.marionette.switch_to_frame()
+
                             # Turn on FPS
                             self.marionette.set_script_timeout(period + 1000)
                             self.logger.debug('Start measuring FPS')
@@ -386,8 +398,10 @@ class B2GPerfRunner(DatazillaPerfPoster):
                     self.post_to_datazilla(results, app_name)
                 else:
                     for key, values in results.iteritems():
-                        result_summary = 'avg:%s, max:%s, min:%s, all:%s' % (
-                            sum(values) / len(values),
+                        result_summary = 'median:%s, mean:%s, std: %s, max:%s, min:%s, all:%s' % (
+                            int(numpy.median(values)),
+                            int(numpy.mean(values)),
+                            int(numpy.std(values)),
                             max(values),
                             min(values),
                             ','.join(str(x) for x in values))
@@ -402,14 +416,22 @@ class B2GPerfRunner(DatazillaPerfPoster):
         if caught_exception:
             sys.exit(1)
 
+    def prepare_app(self, app_name):
+        if app_name.lower() == 'browser':
+            from gaiatest.apps.browser.app import Browser
+            browser = Browser(self.marionette)
+            browser.go_to_url('http://taskjs.org/')
+            tab_frame = self.marionette.execute_script("return window.wrappedJSObject.Browser.currentTab.dom;")
+            self.marionette.switch_to_frame(tab_frame)
+            MarionetteWait(self.marionette, 30).until(lambda m: m.execute_script('return window.document.readyState;', new_sandbox=False) == 'complete')
+
     def scroll_app(self, app_name):
         touch_duration = float(200)
 
-        apps = gaiatest.GaiaApps(self.marionette)
         #wait up to 30secs for the elements we want to show up
         self.marionette.set_search_timeout(30000)
 
-        if app_name == 'Homescreen':
+        if app_name.lower() == 'homescreen':
             action = Actions(self.marionette)
             landing_page = self.marionette.find_element('id', 'landing-page')
             self.logger.debug('Swiping to first page of apps')
@@ -427,26 +449,16 @@ class B2GPerfRunner(DatazillaPerfPoster):
                 first_page.size['width'] / 2,
                 first_page.size['width'] / 100 * 90,
                 first_page.size['width'] / 2, touch_duration).perform()
-        elif app_name == 'Contacts':
+        elif app_name.lower() == 'contacts':
             name = self.marionette.find_element("css selector", ".contact-item p > strong")
             MarionetteWait(self.marionette, 30).until(lambda m: name.is_displayed())
             self.logger.debug('Scrolling through contacts')
             smooth_scroll(self.marionette, name, "y", -1, 5000, scroll_back=False)
-        elif app_name == 'Browser':
-            self.marionette.execute_script("return window.wrappedJSObject.Browser.navigate('http://taskjs.org/');", new_sandbox=False)
-            MarionetteWait(self.marionette, 30).until(lambda m: 'http://taskjs.org/' == m.execute_script('return window.wrappedJSObject.Browser.currentTab.url;', new_sandbox=False))
-            MarionetteWait(self.marionette, 30).until(lambda m: not m.execute_script('return window.wrappedJSObject.Browser.currentTab.loading;', new_sandbox=False))
-            # check when the tab's document is ready
-            tab_frame = self.marionette.execute_script("return window.wrappedJSObject.Browser.currentTab.dom;")
-            self.marionette.switch_to_frame(tab_frame)
-            MarionetteWait(self.marionette, 30).until(lambda m: m.execute_script('return window.document.readyState;', new_sandbox=False) == 'complete')
-            # we have to fire smooth_scroll from the browser app, so let's go back
-            self.marionette.switch_to_frame()
-            apps.launch(app_name)  # since the app is launched, launch will switch us back to the app frame without relaunching
+        elif app_name.lower() == 'browser':
             tab_dom = self.marionette.execute_script("return window.wrappedJSObject.Browser.currentTab.dom;", new_sandbox=False)
             self.logger.debug('Scrolling through browser content')
             smooth_scroll(self.marionette, tab_dom, "y", -1, 5000, scroll_back=True)
-        elif app_name == 'Email':
+        elif app_name.lower() == 'email':
             email = self.marionette.find_element("class name", "msg-header-author")
             MarionetteWait(self.marionette, 30).until(lambda m: email.is_displayed() or not email.get_attribute('hidden'))
             emails = self.marionette.find_elements("class name", "msg-header-author")
@@ -456,7 +468,6 @@ class B2GPerfRunner(DatazillaPerfPoster):
             self.logger.debug('Scrolling through emails')
             smooth_scroll(self.marionette, emails[0], "y", -1, 2000, scroll_back=True)
 
-
 class B2GPerfFormatter(mozlog.MozFormatter):
 
     def format(self, record):
