@@ -24,7 +24,6 @@ class MozPerfHandler(DatazillaPerfPoster):
                 metric = result['title'].strip().replace(' ', '_')
                 results.setdefault(metric, []).extend(result.get('mozPerfDurations'))
 
-            self.post_to_datazilla(results, app_name)
             if self.submit_report:
                 self.post_to_datazilla(results, app_name)
             else:
@@ -46,5 +45,7 @@ if __name__ == "__main__":
 
     marionette = Marionette(host='localhost', port=2828)
     marionette.start_session()
-    handler = MozPerfHandler(marionette, datazilla_config=datazilla_config)
+    handler = MozPerfHandler(marionette,
+                             datazilla_config=datazilla_config,
+                             sources=options.sources)
     handler.process_results(args[0])
